#!/bin/bash

#Global variables
LINE_TO_ADD=""

function get_installation_dir()
{
  # Local variables
  local C_DIR="$(pwd)"
  local PRODUCT="$1"
  local INSTALL_SCRIPT="$2"
  local RETURN_STRING=""
  local FULL_PATH=""
  FOUND_LIST=""

  # Try to guess the installation directory
  RETURN_STRING="${C_DIR%%2X/${PRODUCT}*}2X/${PRODUCT}"
  # Try to test the directory and if successfull return string
  [ -d "${RETURN_STRING}" ] && echo "${RETURN_STRING}" && return 0
  # If not try to find the directory in another way
  # Go to /proc/<process number>/fd and try to find the full path from there
  cd "/proc/$$/fd" 2>/dev/null
  FULL_PATH="$(ls -l | grep "${INSTALL_SCRIPT}" | awk -F"-> " '{print $2}')"
  RETURN_STRING="${FULL_PATH%%2X/${PRODUCT}*}2X/${PRODUCT}"
  # Test again whether the directory exists or not
  [ -d "${RETURN_STRING}" ] && echo "${RETURN_STRING}" && return 0
  # Try to use the find utility
  # Initialize counter
  I=0
  # Use for loop to build array with found results
  for FOUND in $(find / \( -path /proc -prune \) , \( -path /media -prune \) , \( -path /dev -prune \) , -regex .*2X/${PRODUCT}.*/${INSTALL_SCRIPT})
  do
    FOUND_LIST[${I}]="${FOUND}"
    let "I=I+1"
  done
  # More then one entry denotes two installations.  User needs to remove old installation
  [ ${#FOUND_LIST[@]} -gt 1 -o ${#FOUND_LIST[@]} -eq 0 ] && RETURN_STRING="" && echo "${RETURN_STRING}" && return 0
  [ ${#FOUND_LIST[@]} -eq 1 ] && RETURN_STRING="${FOUND_LIST[0]}"
  [ -d "${RETURN_STRING}" ] && echo "${RETURN_STRING}" && return 0
  RETURN_STRING="" && echo "${RETURN_STRING}" && return 1
}

function install_sso()
{
  local INST_DIR="${1}"
  local PAM_MODULE_PATH="${INST_DIR}/share/pam_2xclient.so"
  local PAM_CONFIG="${INST_DIR}/share/2xclient.pam-config"
  local PAM_AUTH_UPDATE_TOOL="$(which pam-auth-update)"
  local RETURN_CODE=1

  if [ ! -f "$PAM_MODULE_PATH" ]
  then
    echo "Installed version of 2X Client does not support SingleSignOn component. Please upgrade first."
    return ${RETURN_CODE}
  fi

  mkdir -p /lib/security/
  cp $PAM_MODULE_PATH /lib/security/ || return ${RETURN_CODE}

  if [ -d /usr/share/pam-configs -a -f "${PAM_AUTH_UPDATE_TOOL}" ]
  then
    # PAM 1.0.1 on Debian derived distos use pam-auth-update to configure the PAM sub system.
    cp ${PAM_CONFIG} /usr/share/pam-configs/2xclient
    ${PAM_AUTH_UPDATE_TOOL} --package
    return $?
  else
    echo "Standard hierarchy required for automated SSO installation not found. Please refer to README.SSO to install module manually."
  fi
  return ${RETURN_CODE}
}

##### MAIN #####
LINE_TO_ADD="$( get_installation_dir "Client" "install_sso.sh" )"

echo
echo "Setup is going to install/update 2X SingleSignOn component."
echo "When this component is installed your credentials will be used automatically."
echo
install_sso $LINE_TO_ADD

exit 0
